==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/fa.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "ذخیره سازی به طور موقت در دسترس نیست",
    "Storage invalid" : "فضای ذخیره‌سازی نامعتبر",
    "Unknown error" : "خطای نامشخص",
    "File could not be found" : "فایل پیدا نمی‌شود",
    "Move or copy" : "انتقال یا کپی",
    "Download" : "دانلود",
    "Delete" : "حذف",
    "Home" : "خانه",
    "Close" : "بستن",
    "Favorites" : "موارد محبوب",
    "Could not create folder \"{dir}\"" : "شاخه \"{dir}\" ساخته نمی‌شود",
    "This will stop your current uploads." : "با این کار آپلودهای فعلی شما متوقف خواهد شد.",
    "Upload cancelled." : "بار گذاری لغو شد",
    "Processing files …" : "پردازش فایل ها",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "امکان آپلود {filename} وجود ندارد، پوشه‌ای با این نام یا فایلی با حجم 0 بایت با این نام وجود دارد",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "ظرفیت لازم وجود ندارد، شما آپلودی با حجم {size1}  را انجام میدهید اما تنها {size2} فضا باقی مانده است",
    "Target folder \"{dir}\" does not exist any more" : "پوشه هدف \"{dir}\" دیگر وجود ندارد",
    "Not enough free space" : "فضای کافی در دسترس نیست",
    "An unknown error has occurred" : "خطایی ناشناخته اتفاق افتاده است",
    "Uploading …" : "بارگذاری...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} از {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "بارگذاری این مورد پشتیبانی نمی شد",
    "Target folder does not exist any more" : "پوشه هدف وجود ندارد",
    "Error when assembling chunks, status code {status}" : "خطا هنگام جمع آوری قطعه ها، کد وضعیت {status}",
    "Actions" : "فعالیت ها",
    "Rename" : "تغییرنام",
    "Copy" : "کپی کردن",
    "Choose target folder" : "پوشه هدف را انتخاب کنید",
    "Open" : "باز کن...",
    "Delete file" : "حذف فایل",
    "Delete folder" : "حذف پوشه",
    "Disconnect storage" : "فضای ذخیره را جدا کنید",
    "Unshare" : "لغو اشتراک",
    "Could not load info for file \"{file}\"" : "بارگیری اطلاعات برای پرونده امکان پذیر نیست \"{file}\"",
    "Files" : "پرونده‌ها",
    "Details" : "جزئیات",
    "Select" : "انتخاب",
    "Pending" : "در انتظار",
    "Unable to determine date" : "امکان تعیین تاریخ وجود ندارد",
    "This operation is forbidden" : "این عملیات غیرمجاز است",
    "This directory is unavailable, please check the logs or contact the administrator" : "پوشه‌ در دسترس نیست، لطفا لاگ‌ها را بررسی کنید یا به مدیر سیستم اطلاع دهید",
    "Could not move \"{file}\", target exists" : "انتقال\"{پرونده}\" امکان پذیر نیست ، هدف وجود دارد",
    "Could not move \"{file}\"" : "فایل \"{file}\" منتقل نمی‌شود",
    "copy" : "کپی",
    "Could not copy \"{file}\", target exists" : "\"{پرونده}\" کپی نشد ، هدف وجود دارد",
    "Could not copy \"{file}\"" : "پرونده کپی نشد",
    "Copied {origin} inside {destination}" : "کپی شده (اصل) در مقصد",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "کپی شده از {مبدا} و {فایل های ام بی} و فایل های دیگر در {مقصد} . ",
    "{newName} already exists" : "{newName} قبلاً موجود است",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "عنوان \"{targetName}\" هم اکنون در پوشه \"{dir}\" وجود دارد. لطفا نام دیگری انتخاب کنید",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" تغییر نام داده نمی‌شود",
    "Could not create file \"{file}\"" : "فایل \"{file}\" ایجاد نمی‌شود",
    "Could not create file \"{file}\" because it already exists" : "نمی توان پرونده \"{file}\" ایجاد کرد زیرا در حال حاضر وجود دارد",
    "Could not create folder \"{dir}\" because it already exists" : "شاخه \"{dir}\" به علت موجود بودن ساخته نشد",
    "Error deleting file \"{fileName}\"." : "خطای حذف فایل \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "جستجو در پوشه های دیگر برای {tag}{filter}{endtag} یافت نشد",
    "Name" : "نام",
    "Size" : "اندازه",
    "Modified" : "تاریخ",
    "_%n folder_::_%n folders_" : ["%n پوشه","%n پوشه"],
    "_%n file_::_%n files_" : ["%n فایل","%n فایل"],
    "{dirs} and {files}" : "{dirs} و {files}",
    "You don’t have permission to upload or create files here" : "شما دسترسی مجاز برای آپلود یا ایجاد فایل در اینجا را ندارید",
    "_Uploading %n file_::_Uploading %n files_" : ["در حال بارگذاری %n فایل","در حال بارگذاری %n فایل"],
    "New" : "جدید",
    "{used} of {quota} used" : "{used} از {quota} استفاده شده",
    "{used} used" : "{used} استفاده شده",
    "\"{name}\" is an invalid file name." : "\"{name}\" نامی نامعتبر برای فایل است.",
    "File name cannot be empty." : "نام پرونده نمی تواند خالی باشد.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" یک نوع پرونده مجاز نیست",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "فضای ذخیر‌سازی {owner}  پر شده است، امکان بروزرسانی یا هم‌گام‌سازی بیشتر وجود ندارد!",
    "Your storage is full, files can not be updated or synced anymore!" : "فضای ذخیره ی شما کاملا پر است، بیش از این فایلها بهنگام یا همگام سازی نمی توانند بشوند!",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "فضای  {owner} تقریبا پر شده است ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "فضای ذخیره ی شما تقریبا پر است ({usedSpacePercent}%)",
    "_matches '{filter}'_::_match '{filter}'_" : ["تطبیق '{filter}'","تطبیق '{filter}'"],
    "View in folder" : "مشاهده در پوشه",
    "Copied!" : "کپی انجام شد!",
    "Path" : "مسیر",
    "_%n byte_::_%n bytes_" : ["%n بایت","%n بایت"],
    "Favorited" : "برگزیده شده",
    "Favorite" : "برگزیده",
    "New folder" : "پوشه جدید",
    "Upload file" : "آپلود فایل",
    "Recent" : "اخیر",
    "Remove from favorites" : "حذف کردن از برگزیده ها",
    "Add to favorites" : "اضافه کردن به برگزیده ها",
    "An error occurred while trying to update the tags" : "یک خطا در حین بروزرسانی برچسب‌ها رخ داده است",
    "Added to favorites" : "محبوب شد",
    "Removed from favorites" : "از محبوب‌ها حذف شد",
    "You added {file} to your favorites" : "شما فایل {file} را برای خودتان محبوب کردید",
    "You removed {file} from your favorites" : "شما فایل {file} را از محبوب‌های خودتان حذف کردید",
    "File changes" : "تغییرات فایل",
    "Created by {user}" : "{user} ٖایجاد کرد",
    "Changed by {user}" : "{user} تغییر داد",
    "Deleted by {user}" : " {user} حذف کرد",
    "\"remote user\"" : "\"کاربران از راه‌ دور\"",
    "A new file or folder has been <strong>created</strong>" : "فایل یا پوشه ای <strong>ایجاد</strong> شد",
    "A file or folder has been <strong>deleted</strong>" : "فایل یا پوشه ای به <strong>حذف</strong> شد",
    "A file or folder has been <strong>restored</strong>" : "یک فایل یا پوشه <strong>بازگردانی شد</strong>",
    "All files" : "تمامی فایل‌ها",
    "Unlimited" : "نامحدود",
    "Upload (max. %s)" : "آپلود (بیشترین سایز %s)",
    "Accept" : "قبول",
    "Reject" : "رد کردن",
    "Change" : "تغییر",
    "Tags" : "برچسب‌ها",
    "%1$s of %2$s used" : "%1$s از %2$s استفاده شده ",
    "Settings" : "تنظیمات",
    "Show hidden files" : "نمایش فایل‌های مخفی",
    "WebDAV" : "WebDAV",
    "Toggle grid view" : "نمای شبکه را تغییر دهید",
    "No files in here" : "هیچ فایلی اینجا وجود ندارد",
    "Upload some content or sync with your devices!" : "محتوایی را آپلود کنید یا با دستگاه خود همگام‌سازی کنید!",
    "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
    "Select all" : "انتخاب همه",
    "Upload too large" : "سایز فایل برای آپلود زیاد است(م.تنظیمات در php.ini)",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "فایلها بیش از حد تعیین شده در این سرور هستند\nمترجم:با تغییر فایل php,ini میتوان این محدودیت را برطرف کرد",
    "No favorites yet" : "هنوز مورد دلخواه وجود ندارد",
    "Files and folders you mark as favorite will show up here" : "فایل‌ها و پوشه‌های انتخاب شده به عنوان برگزیده توسط شما، در اینجا نمایش داده می‌شود",
    "Deleted files" : "فایل های حذف شده",
    "Shares" : "اشتراک گذاری ها",
    "Shared with others" : "موارد به اشتراک گذاشته شده با دیگران",
    "Shared with you" : "Shared with you",
    "Shared by link" : "اشتراک گذاشته شده از طریق لینک",
    "Deleted shares" : "اشتراک گذاری های حذف شده",
    "Pending shares" : "اشتراک در حال انتظار ",
    "Text file" : "فایل متنی",
    "New text file.txt" : "فایل متنی جدید .txt"
},
"nplurals=2; plural=(n > 1);");

==> nextcloud-20.0.0-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files/l10n/fa.js <==
OC.L10N.register(
    "files",
    {
    "Storage is temporarily not available" : "ذخیره سازی به طور موقت در دسترس نیست",
    "Storage invalid" : "فضای ذخیره‌سازی نامعتبر",
    "Unknown error" : "خطای نامشخص",
    "File could not be found" : "فایل پیدا نمی‌شود",
    "Move or copy" : "انتقال یا کپی",
    "Download" : "دانلود",
    "Delete" : "حذف",
    "Home" : "خانه",
    "Close" : "بستن",
    "Favorites" : "موارد محبوب",
    "Could not create folder \"{dir}\"" : "شاخه \"{dir}\" ساخته نمی‌شود",
    "This will stop your current uploads." : "با این کار آپلودهای فعلی شما متوقف خواهد شد.",
    "Upload cancelled." : "بار گذاری لغو شد",
    "Processing files …" : "پردازش فایل ها",
    "…" : "...",
    "Unable to upload {filename} as it is a directory or has 0 bytes" : "امکان آپلود {filename} وجود ندارد، پوشه‌ای با این نام یا فایلی با حجم 0 بایت با این نام وجود دارد",
    "Not enough free space, you are uploading {size1} but only {size2} is left" : "ظرفیت لازم وجود ندارد، شما آپلودی با حجم {size1}  را انجام میدهید اما تنها {size2} فضا باقی مانده است",
    "Target folder \"{dir}\" does not exist any more" : "پوشه هدف \"{dir}\" دیگر وجود ندارد",
    "Not enough free space" : "فضای کافی در دسترس نیست",
    "An unknown error has occurred" : "خطایی ناشناخته اتفاق افتاده است",
    "Uploading …" : "بارگذاری...",
    "{loadedSize} of {totalSize} ({bitrate})" : "{loadedSize} از {totalSize} ({bitrate})",
    "Uploading that item is not supported" : "بارگذاری این مورد پشتیبانی نمی شد",
    "Target folder does not exist any more" : "پوشه هدف وجود ندارد",
    "Error when assembling chunks, status code {status}" : "خطا هنگام جمع آوری قطعه ها، کد وضعیت {status}",
    "Actions" : "فعالیت ها",
    "Rename" : "تغییرنام",
    "Copy" : "کپی کردن",
    "Choose target folder" : "پوشه هدف را انتخاب کنید",
    "Open" : "باز کن...",
    "Delete file" : "حذف فایل",
    "Delete folder" : "حذف پوشه",
    "Disconnect storage" : "فضای ذخیره را جدا کنید",
    "Could not load info for file \"{file}\"" : "بارگیری اطلاعات برای پرونده امکان پذیر نیست \"{file}\"",
    "Files" : "پرونده‌ها",
    "Details" : "جزئیات",
    "Select" : "انتخاب",
    "Pending" : "در انتظار",
    "Unable to determine date" : "امکان تعیین تاریخ وجود ندارد",
    "This operation is forbidden" : "این عملیات غیرمجاز است",
    "This directory is unavailable, please check the logs or contact the administrator" : "پوشه‌ در دسترس نیست، لطفا لاگ‌ها را بررسی کنید یا به مدیر سیستم اطلاع دهید",
    "Could not move \"{file}\", target exists" : "انتقال\"{پرونده}\" امکان پذیر نیست ، هدف وجود دارد",
    "Could not move \"{file}\"" : "فایل \"{file}\" منتقل نمی‌شود",
    "copy" : "کپی",
    "Could not copy \"{file}\", target exists" : "\"{پرونده}\" کپی نشد ، هدف وجود دارد",
    "Could not copy \"{file}\"" : "پرونده کپی نشد",
    "Copied {origin} inside {destination}" : "کپی شده (اصل) در مقصد",
    "Copied {origin} and {nbfiles} other files inside {destination}" : "کپی شده از {مبدا} و {فایل های ام بی} و فایل های دیگر در {مقصد} . ",
    "{newName} already exists" : "{newName} قبلاً موجود است",
    "The name \"{targetName}\" is already used in the folder \"{dir}\". Please choose a different name." : "عنوان \"{targetName}\" هم اکنون در پوشه \"{dir}\" وجود دارد. لطفا نام دیگری انتخاب کنید",
    "Could not rename \"{fileName}\"" : "\"{fileName}\" تغییر نام داده نمی‌شود",
    "Could not create file \"{file}\"" : "فایل \"{file}\" ایجاد نمی‌شود",
    "Could not create file \"{file}\" because it already exists" : "نمی توان پرونده \"{file}\" ایجاد کرد زیرا در حال حاضر وجود دارد",
    "Could not create folder \"{dir}\" because it already exists" : "شاخه \"{dir}\" به علت موجود بودن ساخته نشد",
    "Error deleting file \"{fileName}\"." : "خطای حذف فایل \"{fileName}\".",
    "No search results in other folders for {tag}{filter}{endtag}" : "جستجو در پوشه های دیگر برای {tag}{filter}{endtag} یافت نشد",
    "Name" : "نام",
    "Size" : "اندازه",
    "Modified" : "تاریخ",
    "_%n folder_::_%n folders_" : ["%n پوشه","%n پوشه"],
    "_%n file_::_%n files_" : ["%n فایل","%n فایل"],
    "{dirs} and {files}" : "{dirs} و {files}",
    "You don’t have permission to upload or create files here" : "شما دسترسی مجاز برای آپلود یا ایجاد فایل در اینجا را ندارید",
    "_Uploading %n file_::_Uploading %n files_" : ["در حال بارگذاری %n فایل","در حال بارگذاری %n فایل"],
    "New" : "جدید",
    "{used} of {quota} used" : "{used} از {quota} استفاده شده",
    "{used} used" : "{used} استفاده شده",
    "\"{name}\" is an invalid file name." : "\"{name}\" نامی نامعتبر برای فایل است.",
    "File name cannot be empty." : "نام پرونده نمی تواند خالی باشد.",
    "\"{name}\" is not an allowed filetype" : "\"{name}\" یک نوع پرونده مجاز نیست",
    "Storage of {owner} is full, files can not be updated or synced anymore!" : "فضای ذخیر‌سازی {owner}  پر شده است، امکان بروزرسانی یا هم‌گام‌سازی بیشتر وجود ندارد!",
    "Your storage is full, files can not be updated or synced anymore!" : "فضای ذخیره ی شما کاملا پر است، بیش از این فایلها بهنگام یا همگام سازی نمی توانند بشوند!",
    "_matches '{filter}'_::_match '{filter}'_" : ["تطبیق '{filter}'","تطبیق '{filter}'"],
    "View in folder" : "مشاهده در پوشه",
    "Copied!" : "کپی انجام شد!",
    "Path" : "مسیر",
    "_%n byte_::_%n bytes_" : ["%n بایت","%n بایت"],
    "Favorited" : "برگزیده شده",
    "Favorite" : "برگزیده",
    "New folder" : "پوشه جدید",
    "Upload file" : "آپلود فایل",
    "Recent" : "اخیر",
    "Remove from favorites" : "حذف کردن از برگزیده ها",
    "Add to favorites" : "اضافه کردن به برگزیده ها",
    "An error occurred while trying to update the tags" : "یک خطا در حین بروزرسانی برچسب‌ها رخ داده است",
    "Added to favorites" : "محبوب شد",
    "Removed from favorites" : "از محبوب‌ها حذف شد",
    "You added {file} to your favorites" : "شما فایل {file} را برای خودتان محبوب کردید",
    "You removed {file} from your favorites" : "شما فایل {file} را از محبوب‌های خودتان حذف کردید",
    "File changes" : "تغییرات فایل",
    "Created by {user}" : "{user} ٖایجاد کرد",
    "Changed by {user}" : "{user} تغییر داد",
    "Deleted by {user}" : " {user} حذف کرد",
    "\"remote user\"" : "\"کاربران از راه‌ دور\"",
    "A file or folder has been <strong>changed</strong>" : "فایل یا پوشه ای به <strong>تغییر</strong> یافت",
    "All files" : "تمامی فایل‌ها",
    "Unlimited" : "نامحدود",
    "Upload (max. %s)" : "آپلود (بیشترین سایز %s)",
    "Accept" : "قبول",
    "Reject" : "رد کردن",
    "in %s" : "در %s",
    "Change" : "تغییر",
    "Tags" : "برچسب‌ها",
    "%1$s of %2$s used" : "%1$s از %2$s استفاده شده ",
    "Settings" : "تنظیمات",
    "Show hidden files" : "نمایش فایل‌های مخفی",
    "WebDAV" : "WebDAV",
    "Toggle grid view" : "نمای شبکه را تغییر دهید",
    "No files in here" : "هیچ فایلی اینجا وجود ندارد",
    "Upload some content or sync with your devices!" : "محتوایی را آپلود کنید یا با دستگاه خود همگام‌سازی کنید!",
    "No entries found in this folder" : "هیچ ورودی‌ای در این پوشه وجود ندارد",
    "Select all" : "انتخاب همه",
    "Upload too large" : "سایز فایل برای آپلود زیاد است(م.تنظیمات در php.ini)",
    "The files you are trying to upload exceed the maximum size for file uploads on this server." : "فایلها بیش از حد تعیین شده در این سرور هستند\nمترجم:با تغییر فایل php,ini میتوان این محدودیت را برطرف کرد",
    "No favorites yet" : "هنوز مورد دلخواه وجود ندارد",
    "Files and folders you mark as favorite will show up here" : "فایل‌ها و پوشه‌های انتخاب شده به عنوان برگزیده توسط شما، در اینجا نمایش داده می‌شود",
    "Deleted files" : "فایل های حذف شده",
    "Shares" : "اشتراک گذاری ها",
    "Shared with others" : "موارد به اشتراک گذاشته شده با دیگران",
    "Shared with you" : "Shared with you",
    "Shared by link" : "اشتراک گذاشته شده از طریق لینک",
    "Deleted shares" : "اشتراک گذاری های حذف شده",
    "Pending shares" : "اشتراک در حال انتظار ",
    "Text file" : "فایل متنی",
    "New text file.txt" : "فایل متنی جدید .txt",
    "Unshare" : "لغو اشتراک",
    "Storage of {owner} is almost full ({usedSpacePercent}%)" : "فضای  {owner} تقریبا پر شده است ({usedSpacePercent}%)",
    "Your storage is almost full ({usedSpacePercent}%)" : "فضای ذخیره ی شما تقریبا پر است ({usedSpacePercent}%)",
    "A new file or folder has been <strong>created</strong>" : "فایل یا پوشه ای <strong>ایجاد</strong> شد",
    "A file or folder has been <strong>deleted</strong>" : "فایل یا پوشه ای به <strong>حذف</strong> شد",
    "A file or folder has been <strong>restored</strong>" : "یک فایل یا پوشه <strong>بازگردانی شد</strong>"
},
"nplurals=2; plural=(n > 1);");
